/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fulltext;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;

import org.apache.lucene.analysis.Tokenizer;
import org.apache.lucene.analysis.tokenattributes.CharTermAttribute;
import org.apache.lucene.analysis.tokenattributes.OffsetAttribute;
import org.apache.lucene.analysis.tokenattributes.PositionIncrementAttribute;
import org.tinygroup.chinese.ChineseParser;
import org.tinygroup.springutil.SpringUtil;

public class ChineseTokenStream extends Tokenizer {
	private BufferedReader reader = null;
	private String buffer = null;
	private ChineseParser parser = null;
	private List<org.tinygroup.chinese.Token> result = new ArrayList<org.tinygroup.chinese.Token>();;
	private int index = -1;

	private final CharTermAttribute termAtt = addAttribute(CharTermAttribute.class);
	private final OffsetAttribute offsetAtt = addAttribute(OffsetAttribute.class);
	private final PositionIncrementAttribute posIncrAtt = addAttribute(PositionIncrementAttribute.class);

	public ChineseTokenStream(Reader reader) {
		super(reader);
		this.reader = new BufferedReader(reader);
		parser = SpringUtil.getBean("chineseParser");
	}

	public final boolean incrementToken() throws IOException {
		clearAttributes();
		if (index == -1) {
			while ((buffer = reader.readLine()) != null) {
				parser.segmentWordMax(buffer, result);
			}
			index = 0;
		}
		if (index < result.size()) {
			termAtt.append(result.get(index).getText());
			offsetAtt.setOffset(result.get(index).getStart(), result.get(index)
					.getEnd());
			posIncrAtt.setPositionIncrement(index + 1);
			index++;
			return true;
		} else {
			return false;
		}
	}
}
