/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fulltext.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.lucene.document.Field;
import org.apache.lucene.document.Field.Store;
import org.apache.lucene.document.StringField;
import org.tinygroup.xmlparser.node.XmlNode;

/**
 * xml文件格式索引
 * 
 * @author renhui
 * 
 */
public class XmlNodeIndexProcessor extends AbstractIndexProcessor<XmlNode> {


	/**
	 * 已节点名称作为id索引值
	 */
	public String getId(XmlNode indexObject) {
		return getValue("id",indexObject);
	}

	/**
	 * contents索引值，包含节点属性值与正文内容
	 */
	public String getContents(XmlNode indexObject) {
		StringBuilder builder = new StringBuilder();
		Map<String, String> attributes = indexObject.getAttributes();
		if (attributes != null) {
			for (Entry<String, String> attribute : attributes.entrySet()) {
				builder.append(attribute.getValue()).append(" ");
			}
		}
		builder.append(indexObject.getPureText());
		return builder.toString();
	}

	public List<Field> getExternFieldList(XmlNode indexObject) {
		List<Field> fields=new ArrayList<Field>();
		String nameValue = getValue("name",indexObject);
		Field nameField = new StringField("name", nameValue, Store.YES);
		fields.add(nameField);
		return fields;
	}
	

	private String getValue(String name,XmlNode indexObject) {
		String nameAttribute = indexObject.getAttribute(name);
		if (nameAttribute == null || nameAttribute.equals("")) {
			nameAttribute = indexObject.getNodeName();
		}
		return nameAttribute;
	}

}
